@@ -908,7 +908,10 @@ module SVG
           if show_y_labels
             # x = 0, y = 0 is top left right next to graph area
             y = y_offset - (label_height * count)
-            x = -label_width/2.0 + y_label_font_size/2.0
+            # instead of calculating the middle anchor position, simply use
+            # static offset and anchor end to right-align the labels. See line :936 below.
+            #x = -label_width/2.0 + y_label_font_size/2.0
+            x = 3
 
             if stagger_y_labels and count % 2 == 1
               x -= stagger
@@ -929,7 +932,8 @@ module SVG
             end
             text.text = textStr
             # note text-anchor is at bottom of textfield
-            text.attributes["style"] = "text-anchor: middle"
+            #text.attributes["style"] = "text-anchor: middle"
+            text.attributes["style"] = "text-anchor: end"
             degrees = rotate_y_labels
             text.attributes["transform"] = "translate( -#{font_size} 0 ) " +
                 "rotate( #{degrees} #{x} #{y} ) "
