@@ -55,7 +55,7 @@ module SVG
     #
     # = Examples
     #
-    # http://www.germane-software/repositories/public/SVG/test/plot.rb
+    # https://github.com/lumean/svg-graph2/blob/master/examples/plot.rb
     #
     # = Notes
     #
@@ -180,6 +180,9 @@ module SVG
           "The data provided contained an odd set of "+
           "data points" unless conf[:data].length % 2 == 0
 
+        # clear the min/max x/y range caches
+        clear_cache
+
         # remove nil values
         conf[:data] = conf[:data].compact
 
@@ -223,24 +226,37 @@ module SVG
       X = 0
       Y = 1
 
+      # procedure to clear all the cached variables used in working out the
+      # max and min ranges for the chart
+      def clear_cache
+        @max_x_cache = @min_x_cache = @max_y_cache = @min_y_cache = nil
+      end
+
       def max_x_range
+        return @max_x_cache unless @max_x_cache.nil?
+
         # needs to be computed fresh when called, to cover the use-case:
         # add_data -> burn -> add_data -> burn
         # when values would be cached, the graph is not updated for second burning
         max_value = @data.collect{|x| x[:data][X][-1] }.max
         max_value = max_value > max_x_value ? max_value : max_x_value if max_x_value
-        return max_value
+        @max_x_cache = max_value
+        @max_x_cache
       end
 
       def min_x_range
+        return @min_x_cache unless @min_x_cache.nil?
+
         # needs to be computed fresh when called, to cover the use-case:
         # add_data -> burn -> add_data -> burn
         # when values would be cached, the graph is not updated for second burning
         min_value = @data.collect{|x| x[:data][X][0] }.min
         min_value = min_value < min_x_value ? min_value : min_x_value if min_x_value
-        return min_value
+        @min_x_cache = min_value
+        @min_x_cache
       end
 
+      # calculate the min and max x value as well as the scale division used for the x-axis
       def x_label_range
         max_value = max_x_range
         min_value = min_x_range
@@ -253,6 +269,7 @@ module SVG
         end
         scale_range = max_value - min_value
 
+        # either use the given step size or by default do 9 divisions.
         scale_division = scale_x_divisions || (scale_range / 9.0)
         @x_offset = 0
 
@@ -265,10 +282,13 @@ module SVG
         [min_value, max_value, scale_division]
       end
 
+      # get array of values for the x axis divisions, assuming left-most value starts
+      # exactly where the graph starts.
       def get_x_values
         min_value, max_value, @x_scale_division = x_label_range
+        x_times = ((max_value-min_value)/@x_scale_division).round + 1
         rv = []
-        min_value.step( max_value + @x_scale_division , @x_scale_division ) {|v| rv << v}
+        x_times.times{|v| rv << (min_value + (v * @x_scale_division))}
         return rv
       end
       alias :get_x_labels :get_x_values
@@ -281,18 +301,24 @@ module SVG
       end
 
       def max_y_range
+        return @max_y_cache unless @max_y_cache.nil?
+
         max_value = @data.collect{|x| x[:data][Y].max }.max
         max_value = max_value > max_y_value ? max_value : max_y_value if max_y_value
-        return max_value
+        @max_y_cache = max_value
+        @max_y_cache
       end
 
       def min_y_range
+        return @min_y_cache unless @min_y_cache.nil?
+
         # needs to be computed fresh when called, to cover the use-case:
         # add_data -> burn -> add_data -> burn
         # when values would be cached, the graph is not updated for second burning
         min_value = @data.collect{|x| x[:data][Y].min }.min
         min_value = min_value < min_y_value ? min_value : min_y_value if min_y_value
-        return min_value
+        @min_y_cache = min_value
+        @min_y_cache
       end
 
       def y_label_range
@@ -345,6 +371,7 @@ module SVG
         @graph_height.to_f / (values.length - 1)
       end
 
+      # calculates the x,y coordinates of a datapoint in the plot area
       def calc_coords(x, y)
         coords = {:x => 0, :y => 0}
         # scale the coordinates, use float division / multiplication
